_base_ = './yolox_s_8xb16_300e_coco.py'

# model settings
model = dict(model_type='m', head=dict(model_type='m', ))
